# 🌐 Fagradalsfjall

![image](https://kamangir-public.s3.ca-central-1.amazonaws.com/geo-watch-2024-09-04-Fagradalsfjall-a/geo-watch-2024-09-04-Fagradalsfjall-a-2X.gif?raw=true&random=mJahtfyzlU0VkVYT)

- [Wikipedia](https://en.wikipedia.org/wiki/Fagradalsfjall)
- [Google Map](https://maps.app.goo.gl/zkdc2DNLahc598k48): `lat: 63°54'18"N`, `lon: 22°16'21"W`.

details: [targets.yaml](../targets.yaml).

used by: [`@geo watch`](../).